@@ -213,9 +213,10 @@ class CreatorDesignWindow(tk.Toplevel):
                 "fg": self.getvar('fg'),
                 "selectbg": self.getvar('selectbg'),
                 "selectfg": self.getvar('selectfg'),
-                "light": self.getvar('light'),
                 "border": self.getvar('border'),
-                "inputfg": self.getvar('inputfg')}}
+                "inputfg": self.getvar('inputfg'),
+                "inputbg": self.getvar('inputbg')
+            }}
 
         user_themes['themes'].append(theme)
 
@@ -277,9 +278,10 @@ class CreatorDesignWindow(tk.Toplevel):
                 bg=self.getvar('bg'),
                 selectfg=self.getvar('selectfg'),
                 selectbg=self.getvar('selectbg'),
-                light=self.getvar('light'),
                 border=self.getvar('border'),
-                inputfg=self.getvar('inputfg'))
+                inputfg=self.getvar('inputfg'),
+                inputbg=self.getvar('inputbg')
+            )
         except Exception:
             return
 
@@ -313,7 +315,7 @@ class CreatorDesignWindow(tk.Toplevel):
         img = ImageGrab.grab(bbox=bbox)
 
         # image name
-        filename = f'../docs/images/ttkcreator.png'
+        filename = f'docs/images/ttkcreator.png'
         print(filename)
         img.save(filename, 'png')
 
@@ -389,18 +391,17 @@ class EverythingBagel(ttk.Notebook):
         options_frame.pack(fill='x', pady=10)
 
         # Radio
-        r1 = ttk.Radiobutton(options_frame, value=1, text='Radio one')
+        r1 = ttk.Radiobutton(options_frame, value=1, text='Radio 1')
         r1.pack(side='left', fill='x', expand='yes')
         r1.invoke()
-        r2 = ttk.Radiobutton(options_frame, value=2, text='Radio two')
-        r2.pack(side='left', fill='x', expand='yes')
+        ttk.Radiobutton(options_frame, value=2, text='Radio 2').pack(side='left', fill='x', expand='yes')
 
         # Checkbutton
-        cb1 = ttk.Checkbutton(options_frame, text='Option 1')
+        cb1 = ttk.Checkbutton(options_frame, text='Check 1')
         cb1.pack(side='left', fill='x', expand='yes')
         cb1.invoke()  # checked
 
-        cb2 = ttk.Checkbutton(options_frame, text='Option 2')
+        cb2 = ttk.Checkbutton(options_frame, text='Check 2')
         cb2.pack(side='left', fill='x', expand='yes')
         cb2.invoke()
         cb2.invoke()  # unchecked
@@ -517,7 +518,7 @@ class CreatorBaseChooser(tk.Tk):
 
         showwarning(title="User Defined Themes", message='Please supply a path to save user-defined themes')
         userpath = asksaveasfilename(parent=self, title='User Defined Themes', defaultextension='json',
-                                     initialfile='ttkbootstrap_themes.json', )
+                                     initialfile='ttkbootstrap_themes.json', confirmoverwrite=False, )
         if not userpath:
             showwarning(title='User Defined Themes', message='Cannot save user-defined themes without a valid path')
             return False
